# Security Policy

## Supported Versions

Check below to find which versions are currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 3.x     | :white_check_mark: |
| < 3.0   | :x: |

## Reporting a Vulnerability

You can report a security vulnerability to this email: piotrek.witek@gmail.com

You'll get a response back to your email shortly after we read your report.
After analysis of vulnerability is completed we will send you the results and 
keep you updated about the next steps.
